#!/bin/bash
# 
# Welcome to the OurDelta bakery.
# 2008-11-01
# Peter Lieverdink <peter@openquery.com>
# Arjen Lentz <arjen@openquery.com>
#

# Should whine about packages this script depends on...
# they are not necessarily build-depends for upstream mysql.
# E.g: devscripts, fakeroot, bzr, readlink

# Exit immediately on any error
set -e

# Debug script and command lines
#set -x

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"
BUILD_BASE_DIR="$(pwd)/build-temp-$$"
INSTALLROOT="/usr/local/mysql"

# Source our shared util functions.
#
. ${BAKERY_BASE_DIR}/util/util.sh

if [ ! $# -eq 1 ]; then
	echo "Usage: $0 [tarball]"
	echo "    tarball: ourdelta or ourdelta-sail tarball"
	exit 1
else
	TARBALL="$(readlink -f ${1})"
fi

if [ ! -f ${TARBALL} ]; then
	echo "Can't find tarball: ${1}"
	exit 1
fi

if [ -d ${INSTALLROOT} ]; then
	echo "${INSTALLROOT} exists, move it out of the way first"
	exit 2
fi

# Determine source name
#
SOURCE_DIR=$(basename ${TARBALL} .tar.gz)

# Find out the bakery version, so we can adjust the changelog file later.
#
pushd ${BAKERY_BASE_DIR}/..
if [ ! -f .bzr-version ]; then
    echo "No bzr version info. You are not running this script from a"
    echo "properly exported bakery. Please do so. I will now quit."
    exit 1
else
    source .bzr-version
fi
popd

# Find major.minor version.
#
UPSTREAM="$(echo ${SOURCE_DIR} | cut -d- -f 2)"
MYVER="$(echo ${SOURCE_DIR} | cut -d- -f 2 | cut -d. -f1,2)"

# Whatup?
#
echo "Going to build ${SOURCE_DIR} in ${BUILD_BASE_DIR}"

# Unpack tarball in our build base dir.
#
# test -d ${BUILD_BASE_DIR} && rm -fr ${BUILD_BASE_DIR}
echo "Unpacking tarball"
mkdir ${BUILD_BASE_DIR}
pushd ${BUILD_BASE_DIR}
tar xfz ${TARBALL}

# Copy the correct debian build script and patch tree from
# the bzr co we were invoked from. This way, versions always
# match this build script.
#
pushd "${BUILD_BASE_DIR}/${SOURCE_DIR}"

# Set version info (again)
#
source .ourdelta-version

# for tarball naming
OURDELTA_VERSION_STRING="${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}${REPO_VERSION}-$(uname -o | cut -d '/' -f 2)-$(uname -m)"
# for configure (shows up in SHOW GLOBAL VARIABLES LIKE 'version_%')
SERVER_SUFFIX="-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}"
SERVER_COMMENT="(OurDelta - http://ourdelta.org/)"
SYSTEM_TYPE="$(uname -o)"
MACHINE_TYPE="$(uname -m)"


get_cpuopt

# we need the following to set up proper for Sphinx Engine
sh BUILD/autorun.sh

# Configure the source (make sure all doublequotes are escaped)
# we need g++ and libstdc++ for GRAPH engine
sh -c  "CFLAGS=\"-O2 -fno-omit-frame-pointer  -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector --param=ssp-buffer-size=4 $CPUOPT\" \
	CXXFLAGS=\"-O2 -fno-omit-frame-pointer -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector --param=ssp-buffer-size=4 $CPUOPT\" \
	\
	CC=gcc CXX=g++ ./configure --prefix=\"${INSTALLROOT}\" \
        --exec-prefix=\"${INSTALLROOT}\" \
        --libexecdir=\"${INSTALLROOT}/bin\" \
        --localstatedir=\"${INSTALLROOT}/data\" \
	\
        --with-server-suffix=\"${SERVER_SUFFIX}\" \
        --with-comment=\"${SERVER_COMMENT}\" \
        --with-system-type=\"${SYSTEM_TYPE}\" \
        --with-machine-type=\"${MACHINE_TYPE}\" \
        \
        --enable-shared \
        --enable-static \
        --enable-thread-safe-client \
        --enable-local-infile \
        \
	--with-big-tables \
        --with-libwrap \
        --with-mysqld-ldflags=-all-static \
        --without-openssl \
        --with-yassl \
        --without-docs \
        --without-readline \
        --with-extra-charsets=all \
        --with-innodb \
        \
        --with-archive-storage-engine \
        --with-csv-storage-engine \
        --with-federated-storage-engine \
        --with-blackhole-storage-engine \
        --with-sphinx-storage-engine \
        --with-oqgraph-computation-engine \
        --without-embedded-server \
	--without-ndbcluster \
	"

# Build
make -j4

# Install
make install

# Rename the installed tree.
pushd /usr/local
mv mysql "mysql-${OURDELTA_VERSION_STRING}"

# Tar up the new tree and remove the tree (if success)
echo "Creating tarball ${OURDELTA_VERSION_STRING}"
tar cfz "${BUILD_BASE_DIR}/mysql-${OURDELTA_VERSION_STRING}.tar.gz" "mysql-${OURDELTA_VERSION_STRING}" && rm -fr "mysql-${OURDELTA_VERSION_STRING}"
popd

chown -R openquery:openquery "${BUILD_BASE_DIR}"

# end of autobake script
