#! /bin/bash

# Script to produce MariaDB source tarball from Launchpad bzr repo for OurDelta builds.
#
# Kristian Nielsen <knielsen@knielsen-hq.org>
# Arjen Lentz (arjen@openquery.com)

# Abort on error.
set -e

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"

# For a release, it is important to know which bzr revision was used
# to do the release. So fail if none specified, rather than default to
# latest.
#
# (One can specify last:1 for latest version).
#
# Also, it is best to use revid: specifications, as revno: numbers are
# not stable, and can change whenever new stuff is merged.
#
# After the release, the revision specified here should be tagged (or
# can specify tag: revision if placing tag before release).

BZR_REVSPEC="${1}"
if [ -z "$BZR_REVSPEC" ]; then
	echo 1>&2 "Usage: $0 bzr-revisionspec"
	exit 1
fi
BZR_BRANCH="${2}"
if [ -z "$BZR_BRANCH" ]; then
	BZR_BRANCH="lp:maria/5.1"
fi

. ${BAKERY_BASE_DIR}/../.bzr-version

echo "Checking out sources from bzr repo..."

# this can do terrible things if you run it in ~ (find a better way)
## Make sure we have a shared repository, so we don't have to download
## everything every time.
#
#bzr info . >/dev/null 2>&1 || bzr init-repo .

WORKDIR="build-temp-$$"
test -d "$WORKDIR" && rm -Rf "$WORKDIR"
#using export rather than checkout now, note that needs param swap
bzr export "$WORKDIR" "$BZR_BRANCH"

echo "Building..."

# Lets not default to make -j6, but actually check the number of cores.
AM_MAKEFLAGS="-j$(if [ -f /proc/cpuinfo ] ; then grep -c processor.* /proc/cpuinfo ; else echo 1 ; fi)"
if [ ${AM_MAKEFLAGS} = -j0 ]; then
  AM_MAKEFLAGS=-j1
fi
export AM_MAKEFLAGS

cd "$WORKDIR"
BUILD/compile-dist > ../build.log 2>&1

echo "Making source tarball..."

make dist >> ../build.log 2>&1

# Now re-pack the source tarball with a mariadb- prefix and without the
# -MariaDB suffix (which is now redundant).
DISTNAME="$(make show-dist-name)"
VERSION="$(perl -e '$_ = $ARGV[0]; s/^[^-]+-//; print' "${DISTNAME}")"
echo  >.mariadb-version "PACKAGE_NAME=mariadb"
echo >>.mariadb-version "VERSION=${VERSION}"
echo >>.mariadb-version "RELEASE_NAME=mariadb"
echo >>.mariadb-version "RELEASE_EXTRA="

source .mariadb-version

NEWBASE="${PACKAGE_NAME}-$(echo "${VERSION}" | sed -e 's/-MariaDB//')"

rm -Rf "${DISTNAME}/"
tar zxf "${DISTNAME}.tar.gz"

rm -Rf "${NEWBASE}"
mv "${DISTNAME}" "${NEWBASE}"
# put .mariadb-version file into source tarball
cp .mariadb-version "${NEWBASE}/"
TARBALL="${NEWBASE}.tar.gz"
tar zcf "${TARBALL}" "${NEWBASE}/"
mv "$TARBALL" ..
cd ..
rm -Rf "$WORKDIR"

echo "Successfully made source tarball $TARBALL"
